<?php

namespace Annie\Projects\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Projects\Models\ProjectItem;

class ProjectItemPolicy
{

    /**
     * Determine if the given user can view the project_item.
     *
     * @param UserPolicy $user
     * @param ProjectItem $project_item
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProjectItem $project_item)
    {
        if ($user->canDo('projects.project_item.view') && $user->isAdmin()) {
            return true;
        }

        return $project_item->user_id == user_id() && $project_item->user_type == user_type();
    }

    /**
     * Determine if the given user can create a project_item.
     *
     * @param UserPolicy $user
     * @param ProjectItem $project_item
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('projects.project_item.create');
    }

    /**
     * Determine if the given user can update the given project_item.
     *
     * @param UserPolicy $user
     * @param ProjectItem $project_item
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProjectItem $project_item)
    {
        if ($user->canDo('projects.project_item.edit') && $user->isAdmin()) {
            return true;
        }

        return $project_item->user_id == user_id() && $project_item->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given project_item.
     *
     * @param UserPolicy $user
     * @param ProjectItem $project_item
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProjectItem $project_item)
    {
        return $project_item->user_id == user_id() && $project_item->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given project_item.
     *
     * @param UserPolicy $user
     * @param ProjectItem $project_item
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProjectItem $project_item)
    {
        if ($user->canDo('projects.project_item.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given project_item.
     *
     * @param UserPolicy $user
     * @param ProjectItem $project_item
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProjectItem $project_item)
    {
        if ($user->canDo('projects.project_item.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
