<?php

namespace Annie\Projects\Policies;

use Litepie\User\Contracts\UserPolicy;
use Annie\Projects\Models\ProjectKindSupport;

class ProjectKindSupportPolicy
{

    /**
     * Determine if the given user can view the project_kind_support.
     *
     * @param UserPolicy $user
     * @param ProjectKindSupport $project_kind_support
     *
     * @return bool
     */
    public function view(UserPolicy $user, ProjectKindSupport $project_kind_support)
    {
        if ($user->canDo('projects.project_kind_support.view') && $user->isAdmin()) {
            return true;
        }

        return $project_kind_support->user_id == user_id() && $project_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can create a project_kind_support.
     *
     * @param UserPolicy $user
     * @param ProjectKindSupport $project_kind_support
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('projects.project_kind_support.create');
    }

    /**
     * Determine if the given user can update the given project_kind_support.
     *
     * @param UserPolicy $user
     * @param ProjectKindSupport $project_kind_support
     *
     * @return bool
     */
    public function update(UserPolicy $user, ProjectKindSupport $project_kind_support)
    {
        if ($user->canDo('projects.project_kind_support.edit') && $user->isAdmin()) {
            return true;
        }

        return $project_kind_support->user_id == user_id() && $project_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given project_kind_support.
     *
     * @param UserPolicy $user
     * @param ProjectKindSupport $project_kind_support
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, ProjectKindSupport $project_kind_support)
    {
        return $project_kind_support->user_id == user_id() && $project_kind_support->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given project_kind_support.
     *
     * @param UserPolicy $user
     * @param ProjectKindSupport $project_kind_support
     *
     * @return bool
     */
    public function verify(UserPolicy $user, ProjectKindSupport $project_kind_support)
    {
        if ($user->canDo('projects.project_kind_support.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given project_kind_support.
     *
     * @param UserPolicy $user
     * @param ProjectKindSupport $project_kind_support
     *
     * @return bool
     */
    public function approve(UserPolicy $user, ProjectKindSupport $project_kind_support)
    {
        if ($user->canDo('projects.project_kind_support.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
